#!/bin/bash
# © Copyright [2016 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

# Log files
DATE_NOW=$(date "+%Y-%m-%d %H:%M:%S")
FILE_NAME="activate_cis_scale.sh"
LOG_FILE="/var/opt/novell/log/cis/firewallchange.log"

/sbin/sysctl --system 2>&1 > /dev/null
/sbin/sysctl -w net.ipv4.ip_forward=1

/opt/novell/cis/bin/disable_docker_iptables.sh
if [ $? -ne 0 ]; then
	logger -t cis "Failed to update docker options.\n"
	exit 1;
fi

systemctl start docker
if [ $? -ne 0 ]; then
	logger -t cis "Docker is not running.\n"
	exit 1;
fi

# Load images and enable services
rpm -q --queryformat "%{VERSION} %{RELEASE}\n" sles-oes-cis-data-docker-image >/etc/opt/novell/cis-scale/VERSION

firewallstate=$(firewall-cmd --state 2>&1)
echo "$DATE_NOW - firewall is $firewallstate - $FILE_NAME" >> "$LOG_FILE"
if [ "$firewallstate" == "running" ]; then    
        DEFAULT_ZONE=`firewall-cmd --get-default-zone`
                if [ $? -ne 0 ]; then
                        >&2 echo "$DATE_NOW - Failed to get firewall default zone - $FILE_NAME" >> "$LOG_FILE"
                        exit 1;
                fi

        for port in 8301 8346 8347 8500 18301 18500; do
                firewallop=$(firewall-cmd --permanent --zone=$DEFAULT_ZONE --query-port=${port}/tcp) > /dev/null 2>&1
                echo "$DATE_NOW - firewall port:${port}/tcp is added: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                if [ "$firewallop" != "yes" ]; then
                        firewallop=$(firewall-cmd --permanent --zone=$DEFAULT_ZONE --add-port=${port}/tcp)
                        echo "$DATE_NOW - adding firewall port:${port}/tcp: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                        if [ "$firewallop" != "success" ]; then
                                >&2 echo "$DATE_NOW - Failed to add port: ${port} in firewall - $FILE_NAME" >> "$LOG_FILE"
                                exit 1;
                        fi
                fi
        done

        firewall-cmd --reload
                if [ $? -ne 0 ]; then
                >&2 echo "Firewall reload not successful"
                exit 1;
                fi
else
        DEFAULT_ZONE=`firewall-offline-cmd --get-default-zone`
                if [ $? -ne 0 ]; then
                        >&2 echo "$DATE_NOW - Failed to get firewall offline default zone - $FILE_NAME" >> "$LOG_FILE"
                        exit 1;
                fi

        for port in 8301 8346 8347 8500 18301 18500; do
                firewallop=$(firewall-offline-cmd --zone=$DEFAULT_ZONE --query-port=${port}/tcp) > /dev/null 2>&1
                echo "$DATE_NOW - adding firewall offline port:${port}/tcp is added: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                if [ "$firewallop" != "yes" ]; then
                        firewallop=$(firewall-offline-cmd --zone=$DEFAULT_ZONE --add-port=${port}/tcp) > /dev/null 2>&1
                        echo "$DATE_NOW - adding firewall offline port:${port}/tcp: $firewallop - $FILE_NAME" >> "$LOG_FILE"
                        if [ "$firewallop" != "success" ]; then
                                >&2 echo "$DATE_NOW - Failed to add port: ${port} in firewall offline - $FILE_NAME" >> "$LOG_FILE"
                                exit 1;
                        fi
                fi
        done
fi

if [ `systemctl is-active oes-cis-fluentbit.service` == "active" ]; then
    systemctl stop oes-cis-fluentbit.service
fi

systemctl disable oes-cis-fluentbit.service 2>/dev/null

docker network inspect -f "{{(index (.IPAM.Config) 0).Subnet}}" cisnet 2>/dev/null
if [ $? -ne 0 ]; then
    docker network create --driver=bridge --subnet=172.16.0.0/16 --gateway=172.16.0.1 cisnet
    if [ $? -ne 0 ]; then
        logger -t cis "Docker network create failed.\n"
        exit 1
    fi
    systemctl restart docker
    if [ $? -ne 0 ]; then
        logger -t cis "Docker is not running.\n"
        exit 1;
    fi
fi
