#!/bin/bash
# © Copyright [2018 - 2020, 2024, 2025] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

# Log files
DATE_NOW=$(date "+%Y-%m-%d %H:%M:%S")
FILE_NAME="activate_configuration.sh"
LOG_FILE="/var/opt/novell/log/cis/firewallchange.log"

if [ $# -eq 0 ]
    then
        /opt/novell/cis/bin/disable_docker_iptables.sh
        if [ $? -ne 0 ]; then
            logger -t cis "Failed to update docker options.\n"
            exit 1;
        fi
    
        systemctl start docker
        if [ $? -ne 0 ]; then
            systemctl restart docker
            if [ $? -ne 0 ]; then
                logger -t cis "Docker is not running.\n"
                exit 1;
            fi
        fi

        /bin/bash /opt/novell/cis/bin/activate_cis.sh

        docker load -i /usr/share/suse-docker-images/sles-oes-cis-gateway-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-data-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-metadata-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-policy-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-mgmt-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-auth-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-aggregator-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-collector-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-cis-repcollector-*.tar.xz
    	docker load -i /usr/share/suse-docker-images/sles-oes-cis-repaggregator-*.tar.xz
        docker load -i /usr/share/suse-docker-images/sles-oes-dashboard-*.tar.xz

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-gateway-docker-image`
        CUR_VERSION=`docker images microfocus/cis-gateway | grep "microfocus/cis-gateway" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-gateway:$CUR_VERSION microfocus/cis-gateway:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-data-docker-image`
        CUR_VERSION=`docker images microfocus/cis-data | grep "microfocus/cis-data" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-data:$CUR_VERSION microfocus/cis-data:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-metadata-docker-image`
        CUR_VERSION=`docker images microfocus/cis-metadata | grep "microfocus/cis-metadata" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-metadata:$CUR_VERSION microfocus/cis-metadata:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-policy-docker-image`
        CUR_VERSION=`docker images microfocus/cis-policy | grep "microfocus/cis-policy" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-policy:$CUR_VERSION microfocus/cis-policy:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-mgmt-docker-image`
        CUR_VERSION=`docker images microfocus/cis-mgmt | grep "microfocus/cis-mgmt" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-mgmt:$CUR_VERSION microfocus/cis-mgmt:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-auth-docker-image`
        CUR_VERSION=`docker images microfocus/cis-auth | grep "microfocus/cis-auth" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-auth:$CUR_VERSION microfocus/cis-auth:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-aggregator-docker-image`
        CUR_VERSION=`docker images microfocus/cis-aggregator | grep "microfocus/cis-aggregator" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-aggregator:$CUR_VERSION microfocus/cis-aggregator:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-collector-docker-image`
        CUR_VERSION=`docker images microfocus/cis-collector | grep microfocus/cis-collector | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-collector:$CUR_VERSION microfocus/cis-collector:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-repaggregator-docker-image`
        CUR_VERSION=`docker images microfocus/cis-repaggregator | grep "microfocus/cis-repaggregator" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-repaggregator:$CUR_VERSION microfocus/cis-repaggregator:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-repcollector-docker-image`
        CUR_VERSION=`docker images microfocus/cis-repcollector | grep "microfocus/cis-repcollector" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-repcollector:$CUR_VERSION microfocus/cis-repcollector:$IMAGE_VERSION

        IMAGE_VERSION=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-dashboard-docker-image`
        CUR_VERSION=`docker images microfocus/oes-dashboard | grep "microfocus/oes-dashboard" | awk -F ' ' '{print $2}'`
        docker tag microfocus/oes-dashboard:$CUR_VERSION microfocus/oes-dashboard:$IMAGE_VERSION

        /bin/bash /opt/novell/cis/zk/bin/zk_service.sh load
        /bin/bash /opt/novell/cis/kafka/bin/kafka_service.sh load
        /bin/bash /opt/novell/cis/analytics/bin/os_service.sh load

        if [ ! -d /etc/opt/novell/cis_local ] ; then
            if [ ! -L /etc/opt/novell/cis ] ; then
                /bin/mv  /etc/opt/novell/cis /etc/opt/novell/cis_local
                ln -fsn /etc/opt/novell/cis_local /etc/opt/novell/cis
            fi
        fi

        if [ ! -d /var/opt/novell/log/cis_local ] ; then
            if [ ! -L /var/opt/novell/log/cis ] ; then
                /bin/mv  /var/opt/novell/log/cis /var/opt/novell/log/cis_local
                ln -fsn /var/opt/novell/log/cis_local /var/opt/novell/log/cis
            fi
        fi
        
        conf='/etc/opt/novell/cis/config'
        configServiceIp=$(/sbin/ip addr show dev eth0 |   grep 'inet ' | awk '{print $2}' | cut -d/ -f1 )
        if [ $? -ne 0 ]; then
            logger -t cis "Unable to get Configuration service IP."
            exit 1;
        fi
        sed -i '/IP_CONFIG/ c\IP_CONFIG="'"$configServiceIp"'"' $conf

        # Certificate Management
        if ! { [ -e /etc/ssl/servercerts/servercert.pem ] && [ -e /etc/ssl/servercerts/serverkey.pem ] && [ -e /etc/opt/novell/certs/SSCert.pem ]; }; then
            logger -t cis "Server certificates not found"
            exit 1;
        fi

        if { [ -e /etc/opt/novell/cis/certs/servercert.pem ] && [ -e /etc/opt/novell/cis/certs/serverkey.pem ] && [ -e /etc/opt/novell/cis/certs/rootCAs/SSCert.pem ]; }; then
            mv /etc/opt/novell/cis/certs/servercert.pem /etc/opt/novell/cis/backup/certs
            mv /etc/opt/novell/cis/certs/serverkey.pem /etc/opt/novell/cis/backup/certs
            mv /etc/opt/novell/cis/certs/rootCAs/SSCert.pem /etc/opt/novell/cis/backup/certs/rootCAs
        fi

        # Copying temp certs for starting Configuration wizard
        mkdir -p /etc/opt/novell/cis/certs/rootCAs
        cp /etc/ssl/servercerts/servercert.pem /etc/opt/novell/cis/certs
        cp /etc/ssl/servercerts/serverkey.pem /etc/opt/novell/cis/certs
        cp /etc/opt/novell/certs/SSCert.pem /etc/opt/novell/cis/certs/rootCAs

        /opt/novell/cis/bin/appendcert -dir /etc/opt/novell/certs/ -leaf /etc/ssl/servercerts/servercert.pem -chain /etc/opt/novell/cis/certs/rootCAs/SSCert.pem

        #Enabling services
        systemctl enable docker.service
        systemctl enable oes-cis-configuration.service
        systemctl enable oes-cis-fluentbit.service
        systemctl enable cis-telemetry.timer
        systemctl enable cis-telemetry.service        

        #Starting services required to bring up Configuration UI
        systemctl start oes-cis-updateiptables.service
        systemctl start oes-cis-fluentbit.service
        systemctl start oes-cis-configuration.service
        systemctl start cis-telemetry.timer

        configStatus="/etc/opt/novell/cis/status.json"
        /opt/novell/cis/bin/jsoneditor -file $configStatus -field "cisConfigSuccess" -value "true"

        firewallstate=$(firewall-cmd --state 2>&1)
        echo "${DATE_NOW} - firewall is ${firewallstate} - activate_configuration.sh" >> "$LOG_FILE"
        if [ "$firewallstate" == "running" ]; then             
            firewallop=$(firewall-cmd --query-masquerade --permanent) > /dev/null 2>&1
            echo "$DATE_NOW - firewall query masquerade: $firewallop - $FILE_NAME" >> "$LOG_FILE"
            if [ "$firewallop" != "yes" ]; then
                firewallop=$(firewall-cmd --add-masquerade --permanent)
                echo "$DATE_NOW - adding firewall masquerade: $firewallop - $FILE_NAME" >> "$LOG_FILE"
            fi
        else
            firewallop=$(firewall-offline-cmd --query-masquerade) > /dev/null 2>&1
                echo "$DATE_NOW - firewall offline query masquerade: $firewallop - $FILE_NAME" >> "$LOG_FILE"
            if [ "$firewallop" != "yes" ]; then
                firewallop=$(firewall-offline-cmd --add-masquerade)
                echo "$DATE_NOW - adding firewall offline masquerade: $firewallop - $FILE_NAME" >> "$LOG_FILE"
            fi
        fi

        line="0 0 * * 0 /opt/novell/cis/bin/purge_log_files.sh"
        (crontab -u root -l; echo "$line" ) | crontab -u root -

elif [ $# -eq 1 -a $1 = "--cleanup" ]
    then
        docker rmi microfocus/cis-data 2>/dev/null
        docker rmi microfocus/cis-metadata 2>/dev/null
        docker rmi microfocus/cis-policy 2>/dev/null
        docker rmi microfocus/cis-mgmt 2>/dev/null
        docker rmi microfocus/cis-auth 2>/dev/null
        docker rmi microfocus/cis-aggregator 2>/dev/null
        docker rmi microfocus/cis-collector 2>/dev/null
        docker rmi microfocus/cis-repaggregator 2>/dev/null
        docker rmi microfocus/cis-repcollector 2>/dev/null
        docker rmi microfocus/oes-dashboard 2>/dev/null
        docker rmi fluent/fluentd:v0.12-debian 2>/dev/null
fi
